<mailhistory>
    <style>
        #mailhistory-search-item, #search-from, #search-to, #search-status, #search-retryCount  {
            display: flex;
        }
        #search-menu {
            margin-top: 30px;
            margin-right: 30px;
        }
        #start, #end {
            width: 120px;
        }
        #search-from, #search-to, #search-status {
            margin-right: 10px;
        }
        label {
            margin-top: 5px;
            margin-right: 5px;
        }
        #search-status label {
            width: 110px;
        }
        #search-retryCount label {
            width: 190px;
        }
    </style>
    <div id="mailhistory-search-item" class="hide">
        <div id="search-from">
            <label for="start">From: </label>
            <input type="text" id="start" name="start" class="form-control datetimepicker" value="{start}" />
        </div>
        <div id="search-to">
            <label for="end">To: </label>
            <input id="end" name="end" class="form-control datetimepicker" value="{ end }"/>
        </div>
        <div id="search-status">
            <label for="status">送信状態: </label>
            <select id="status" name="status" class="form-control">
                <option value="-1">全て</option>
                <option value="0">未送信</option>
                <option value="1">送信完了</option>
                <option value="2">送信エラー</option>
            </select>
        </div>
        <div id="search-retryCount">
            <label for="retryCount">リトライ回数: </label>
            <select id="retryCount" name="retryCount" class="form-control">
                <option value="-1">全て</option>
                <option value="0">0回</option>
                <option value="1">1回</option>
                <option value="2">2回</option>
                <option value="3">3回</option>
                <option value="4">4回</option>
                <option value="5">5回</option>
            </select>
        </div>
    </div>
    <data/>
    <script>
        export default {
            onBeforeMount(props, state) {
                moment.locale('ja')
                this.start = moment().format('YYYY-MM-DD')
                this.end = moment().format('YYYY-MM-DD')
                this.scrutiny = props.scrutiny
                this.logoutModal = props.logoutModal
            },
            onMounted(props, states) {
                clearErrorMessage()
                RiotUtil.next("data", {
                    scrutiny: this.scrutiny,
                    logoutModal: this.logoutModal,
                    title: "メール送信履歴",
                    name: 'mailhistory',
                    items: ["送信日時", "送信状態", "リトライ回数","送信先メールアドレス", "タイトル", "本文", "エラー情報"],
                    service: new MailHistoryService(),
                    order: [[1, 'desc']],
                    leftButtons: [{
                        label: '検索',
                        onclick: function (e) {
                            $("#mailhistory_datatables").dataTable().api().ajax.reload()
                        }
                    }],
                    buttons: function (dataTable, editor) {
                    },
                    ajax: async function (handler) {

                        const start = $('#start').val() ? $('#start').val() : ''
                        let end = $('#end').val() ? $('#end').val() : ''
                        if (end) {
                            end = moment(end).add(1, 'days').format('YYYY-MM-DD')
                        }
                        const response = await this.service.search(start, end)
                        if (response.status != "OK" || !response.data || response.data.length < 1) {
                            return handler([])
                        }

                        const status = $('#status').val()
                        let data = response.data
                        if (status > -1) {
                            data = data.filter(item => {
                                return item.status == status
                            })
                        }
                        const retryCount = $('#retryCount').val()
                        if (retryCount > -1) {
                            data = data.filter(item => {
                                return item.seqNo == retryCount
                            })
                        }
                        data.sort(function (a, b) {
                            if (a.sendAt && b.sendAt) {
                                if (a.sendAt < b.sendAt) return -1;
                                if (a.sendAt > b.sendAt) return 1;
                            }
                            return 0;
                        })
                        handler(data)
                    },
                    initComplete: function(dt, data) {
                        $('#mailhistory-search-item').removeClass('hide')
                        $('admincontent #search-menu').prepend($('#mailhistory-search-item'))

                        $('.datetimepicker').datetimepicker({
                            dayViewHeaderFormat: 'YYYY年MM月',
                            stepping: 1,
                            locale:'ja',
                            format : 'YYYY-MM-DD'
                        });
                    },
                    addJSON: function (json) {
                        json.columns.forEach(function (column) {
                            if (column.data == 'status') {
                                column.render = function (data, type, row) {
                                    const code = Code.SEND_STATUS.filter(code => {
                                        return code.value == data
                                    })[0]
                                    return code.label
                                }
                            }
                            if (column.data == 'seqNo') {
                                column.render = function (data, type, row) {
                                    return `${data}回`
                                }
                            }
                        })
                        return json
                    }
                }, "datatables")
            },
            search: function (e) {
                $("#mailhistory_datatables").dataTable().api().ajax.reload()
            }
        }

        function trim(data) {
            if (data == ' ') {
                return ''
            }
            return data
        }

        function clearErrorMessage() {
            $("#error-message").text('').addClass('hide')
        }
        function setErrorMessage(message) {
            $("#error-message").text(message).removeClass('hide')
        }
    </script>
</mailhistory>
